Skip to content

Room

class Room extends Node2D

Description

Base class for creating rooms in GonerEngine's custom room system

When making a new room scene, set a Room node as the root node.

Methods

static func goto(room: PackedScene) -> void

Change the room to a specified loaded room resource

gdscript
Room.goto(load("res://scenes/overworld/rooms/hometown.tscn"))

static func warp_party(target_marker_id: int, facing: Enums.Facing) -> void

Set all your PartyMember's positions to a TargetMarkerDest with a given target_marker_id and set their facing directions.

gdscript
Room.warp_party(1, Enums.Facing.LEFT)